a:link {
	text-decoration: none;
	color: #0000C8;
}
a:visited {
	text-decoration: none;
	color: #000096;
}
a:hover {
	text-decoration: underline;
	color: #0000C8;
}
a:active {
	text-decoration: underline;
	color: #0000C8;
}
body {
	background-color: #F5F5FF;
	color: #000000;
}
.globtable {
	width: 100%;
	border-spacing: 10px;
}
.subtable {
	width: 100%;
}
.globtitle {
	background-color: #505050;
	color: #F5F5FF;
	font-size: 20px;
	font-family: Verdana,Arial,Helvetica,sans-serif,monospace;
}
.subtitle {
	background-color: #808080;
	color: #F5F5FF;
	font-size: 14px;
	font-family: Verdana,Arial,Helvetica,sans-serif,monospace;
}
.entry {
	background-color:#E0E0E0;
	color:#000000;
	font-size: 14px;
	font-family: Verdana,Arial,Helvetica,sans-serif,monospace;
}
.value {
	background-color:#E0E0E0;
	color:#000000;
	font-size: 14px;
	font-family: Verdana,Arial,Helvetica,sans-serif,monospace;
}
